@@ -6,17 +6,25 @@ OC.L10N.register(
     "copy" : "eil",
     "Done" : "Graet",
     "Cancel" : "Arrest",
+    "Drop your files to upload" : "Laoskit ho restroù evit pellkas",
     "Details" : "Munudoù",
     "Sharing" : "Rannan",
     "Tags" : "Klavioù",
     "Can edit" : "Posuple eo embann",
+    "Can share" : "Galout a ra rannañ",
     "Delete" : "Dilemel",
     "Edit" : "Cheñch",
     "Description" : "Diskrivadur",
+    "Comments" : "Displegadennoù",
     "Modified" : "Cheñchet",
-    "Save" : "Entilañ",
+    "Save" : "Enrollañ",
     "Reply" : "Respont",
+    "Update" : "Adnevesaat",
+    "(group)" : "(strollad)",
     "seconds ago" : "eilenn zo",
-    "Shared with you" : "Rannet ganeoc'h"
+    "Shared with you" : "Rannet ganeoc'h",
+    "Today" : "Hiziv",
+    "Tomorrow" : "Warc'hoaz",
+    "This week" : "Er sizhun-mañ"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
