@@ -15,13 +15,16 @@ OC.L10N.register(
     "Delete" : "Dileu",
     "Edit" : "Golygu",
     "Title" : "Teitl",
-    "Description" : "Disgrifiad",
-    "Modified" : "Addaswyd",
     "Upload attachment" : "Llwytho atodiad",
+    "Description" : "Disgrifiad",
+    "Select Date" : "Dewis Dyddiad",
+    "Modified" : "Addaswyd",
     "Save" : "Cadw",
     "Update" : "Diweddaru",
     "seconds ago" : "eiliad yn ôl",
     "Shared with you" : "Shared with you",
-    "An error occurred" : "Digwyddodd gwall"
+    "An error occurred" : "Digwyddodd gwall",
+    "Today" : "Heddiw",
+    "This week" : "Wythnos yma"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
