@@ -20,6 +20,7 @@ OC.L10N.register(
     "Save" : "සුරකින්න",
     "Update" : "යාවත්කාල කිරීම",
     "seconds ago" : "තත්පරයන්ට පෙර",
-    "Shared with you" : "Shared with you"
+    "Shared with you" : "Shared with you",
+    "Today" : "අද"
 },
 "nplurals=2; plural=(n != 1);");
