@@ -98,8 +98,8 @@ OC.L10N.register(
     "No file uploaded or file size exceeds maximum of %s" : "Nenahral sa žiadny súbor alebo jeho veľkosť presiahla %s",
     "Personal planning and team project organization" : "Osobné plánovanie a organizácia tímových projektov",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Karty sú nástroj zacielený na osobné alebo projektové plánovanie tímov v štýle Kanban integrovaný do Nextcloud.\n\n\n- 📥 Zadávajte a usporadúvajte svoje úlohy do kariet\n- 📄 Zapisujte si dodatočné poznámky\n- 🔖 Priraďujte štítky pre ešte lepšiu organizáciu\n- 👥 Zdieľajte so svojim tímom, priateľmi alebo rodinou\n- 🚀 Dostaňte svoj projekt pod kontrolu",
-    "Create new board" : "Vytvoriť novú nástenku",
-    "new board" : "nová nástenka",
+    "Card details" : "Podrobnosti o karte",
+    "Add board" : "Pridať nástenk",
     "Select the board to link to a project" : "Vybrať nástenku na vytvorenie odkazu ku projektu",
     "Search by board title" : "Vyhľadávanie podľa názvu nástenky",
     "Select board" : "Vybrať nástenku",
@@ -116,11 +116,12 @@ OC.L10N.register(
     "This board is read only" : "Táto nástenka je iba na čítanie",
     "Drop your files to upload" : "Pretiahnite sem súbory, ktoré chcete nahrať",
     "Archived cards" : "Archivované karty",
-    "Add new list" : "Pridať nový zoznam",
+    "Add list" : "Pridať zoznam",
     "List name" : "Názov zoznamu",
     "Apply filter" : "Uplatniť filter",
     "Filter by tag" : "Filtrovať podľa štítkov",
     "Filter by assigned user" : "Filtrovať podľa priradeného používateľa",
+    "Unassigned" : "Nepriradený",
     "Filter by due date" : "Filtrovať podľa termínu",
     "Overdue" : "Po termíne",
     "Next 24 hours" : "Ďalších 24 hodín",
@@ -128,10 +129,13 @@ OC.L10N.register(
     "Next 30 days" : "Následujúcich 30 dní",
     "No due date" : "Bez termínu",
     "Clear filter" : "Vyčistiť filter",
+    "Hide archived cards" : "Skryť archivované karty",
     "Show archived cards" : "Zobraziť archivované karty",
     "Toggle compact mode" : "Vyp/zap. kompaktný režim",
     "Details" : "Podrobnosti",
     "Loading board" : "Načítanie nástenky",
+    "No lists available" : "Nie sú k dispozícii žiadne zoznamy",
+    "Create a new list to add cards to this board" : "Pre pridanie kariet na túto tabuľu vytvorte nový zoznam",
     "Board not found" : "Nástenka nebola nájdená",
     "Sharing" : "Sprístupnenie",
     "Tags" : "Štítky",
@@ -149,14 +153,17 @@ OC.L10N.register(
     "Can manage" : "Môže spravovať",
     "Delete" : "Zmazať",
     "Add a new list" : "Pridať nový zoznam",
+    "Archive all cards" : "Archivovať všetky karty",
     "Delete list" : "Vymazať zoznam",
     "Add card" : "Pridať kartu",
+    "Archive all cards in this list" : "Archivovať všetky karty v tomto zozname",
     "Add a new card" : "Pridať novú kartu",
     "Edit" : "Upraviť",
     "Add a new tag" : "Pridať nový štítok",
     "title and color value must be provided" : "je potrebné zadať nadpis a vybrať farbu",
     "Title" : "Názov",
     "Members" : "Členovia",
+    "Upload attachment" : "Nahrať prílohu",
     "Add this attachment" : "Pridať túto prílohu",
     "Delete Attachment" : "Odstrániť prílohu",
     "Restore Attachment" : "Obnoviť prílohu",
@@ -177,9 +184,9 @@ OC.L10N.register(
     "Attachments" : "Prílohy",
     "Comments" : "Komentáre",
     "Choose attachment" : "Vybrať prílohu",
+    "Select Date" : "Vybrať dátum",
     "Modified" : "Upravené",
     "Created" : "Vytvorené",
-    "Upload attachment" : "Nahrať prílohu",
     "No comments yet. Begin the discussion!" : "Zatiaľ bez komentárov. Začnite diskusiu!",
     "Save" : "Uložiť",
     "The comment cannot be empty." : "Komentár nemôže byť prázdny.",
@@ -189,22 +196,20 @@ OC.L10N.register(
     "Update" : "Aktualizovať",
     "(group)" : "(skupina)",
     "(circle)" : "(okruh)",
-    "seconds ago" : "pred niekoľkými sekundami",
     "Assign to me" : "Priradiť mne",
     "Unassign myself" : "Zrušiť priradenie mne",
     "Unarchive card" : "Zrušiť archiváciu karty",
     "Archive card" : "Archivovať kartu",
     "Delete card" : "Zmazať kartu",
     "Move card" : "Presunúť kartu",
-    "Card details" : "Podrobnosti o karte",
     "Move card to another board" : "Presunúť kartu na inú nástenku",
     "Select a list" : "Vybrať zoznam",
+    "seconds ago" : "pred niekoľkými sekundami",
     "All boards" : "Všetky nástenky",
     "Archived boards" : "Archivované nástenky",
     "Shared with you" : "Vám sprístupnené",
     "Limit deck usage of groups" : "Obmedziť použitie Deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Obmedzenie Násteniek bráni používateľom, ktorí nie sú súčasťou týchto skupín, aby si vytvárali vlastné nástenky. Môžu však stále pracovať na nástenkách, ktoré im niekto sprístupní.",
-    "New board title" : "Názov novej nástenky",
     "Edit board" : "Upraviť nástenku",
     "Clone board " : "Zdvojiť nástenku",
     "Unarchive board " : "Zrušiť archiváciu nástenky",
@@ -215,6 +220,9 @@ OC.L10N.register(
     "An error occurred" : "Vyskytla sa chyba",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "Naozaj chcete chcete vymazať nástenku {title}? Toto zmaže všetky údaje o tejto nástenke.",
     "Delete the board?" : "Vymazať nástenku?",
+    "Today" : "Dnes",
+    "Tomorrow" : "Zajtra",
+    "This week" : "Tento týždeň",
     "Link to a board" : "Odkaz na nástenku",
     "Link to a card" : "Prepojiť s kartou",
     "Something went wrong" : "Niečo sa pokazilo",
