@@ -146,6 +146,11 @@ class StackService {
 		return $stacks;
 	}
 
+	public function findCalendarEntries($boardId) {
+		$this->permissionService->checkPermission(null, $boardId, Acl::PERMISSION_READ);
+		return $this->stackMapper->findAll($boardId);
+	}
+
 	public function fetchDeleted($boardId) {
 		$this->permissionService->checkPermission($this->boardMapper, $boardId, Acl::PERMISSION_READ);
 		$stacks = $this->stackMapper->findDeleted($boardId);
